==> apache-tez-0.9.2-src.tar.gz: apache-tez-0.9.2-src/tez-dag/src/main/java/org/apache/tez/dag/app/dag/event/TaskAttemptEventOutputFailed.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app.dag.event;

import org.apache.tez.dag.records.TaskAttemptTerminationCause;
import org.apache.tez.dag.records.TezTaskAttemptID;
import org.apache.tez.runtime.api.impl.TezEvent;

public class TaskAttemptEventOutputFailed extends TaskAttemptEvent 
  implements TaskAttemptEventTerminationCauseEvent {
  
  private TezEvent inputFailedEvent;
  private int consumerTaskNumber;
  
  public TaskAttemptEventOutputFailed(TezTaskAttemptID attemptId,
      TezEvent tezEvent, int numConsumers) {
    super(attemptId, TaskAttemptEventType.TA_OUTPUT_FAILED);
    this.inputFailedEvent = tezEvent;
    this.consumerTaskNumber = numConsumers;
  }
  
  public TezEvent getInputFailedEvent() {
    return inputFailedEvent;
  }
  
  public int getConsumerTaskNumber() {
    return consumerTaskNumber;
  }

  @Override
  public TaskAttemptTerminationCause getTerminationCause() {
    return TaskAttemptTerminationCause.OUTPUT_LOST;
  }
  
}

==> apache-tez-0.10.4-src.tar.gz: apache-tez-0.10.4-src/tez-dag/src/main/java/org/apache/tez/dag/app/dag/event/TaskAttemptEventOutputFailed.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app.dag.event;

import org.apache.tez.dag.records.TaskAttemptTerminationCause;
import org.apache.tez.dag.records.TezTaskAttemptID;
import org.apache.tez.runtime.api.impl.TezEvent;

public class TaskAttemptEventOutputFailed extends TaskAttemptEvent 
  implements TaskAttemptEventTerminationCauseEvent {
  
  private TezEvent inputFailedEvent;
  private int consumerTaskNumber;
  
  public TaskAttemptEventOutputFailed(TezTaskAttemptID sourceTaskAttemptId,
      TezEvent tezEvent, int numConsumers) {
    super(sourceTaskAttemptId, TaskAttemptEventType.TA_OUTPUT_FAILED);
    this.inputFailedEvent = tezEvent;
    this.consumerTaskNumber = numConsumers;
  }
  
  public TezEvent getInputFailedEvent() {
    return inputFailedEvent;
  }
  
  public int getConsumerTaskNumber() {
    return consumerTaskNumber;
  }

  @Override
  public TaskAttemptTerminationCause getTerminationCause() {
    return TaskAttemptTerminationCause.OUTPUT_LOST;
  }
  
}
